@@ -64,8 +64,9 @@ class ModuleStatusModel:
     branch = ''
     msg = ''
     tag = ''
+    git = ''
 
-    def __init__(self, module, pod, res, branch, msg='', tag=''):
+    def __init__(self, module, pod, res, branch, msg='', tag='', git=''):
         """
         :param module: 模块名字
         :param pod: pod名字
@@ -79,6 +80,7 @@ class ModuleStatusModel:
         self.msg = msg
         self.branch = branch
         self.tag = tag
+        self.git = git
 
 
 # 读取yaml文件数据
@@ -443,14 +445,14 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
         index += 1
     # print("convert=======" + str(dependenceList))
     except_list = [
-        module for module in branch_result if module.module not in [
-            pod.module for pod in conver_deplist]]
+        module for module in branch_result if ((module.result == 1) and (module.module not in [
+            pod.module for pod in conver_deplist]))]
     if len(except_list) > 0:
         for mo_re in except_list:
             module_dict = {
                 "module": mo_re.module,
-                "pod": a.pod,
-                "git": a.git,
+                "pod": mo_re.pod,
+                "git": mo_re.git,
                 "branch": n_branch
             }
             dependenceList.append(module_dict)
@@ -483,12 +485,12 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
                 local_dependenceList = []
             # 转换成模型数组
             conver_deplist = load_yaml(local_dependenceList)
-        debugInfo(str([a.module for a in conver_deplist]))
-        debugInfo(str([a.module for a in branch_result]))
+        # debugInfo(str([a.module for a in conver_deplist]))
+        # debugInfo(str([a.module for a in branch_result]))
         except_list = [
             module for module in branch_result if ((module.result == 1) and (module.module not in [
                 pod.module for pod in conver_deplist]))]
-        debugInfo(str([a.module for a in except_list]))
+        # debugInfo(str([a.module for a in except_list]))
         if len(except_list) > 0:
             for mo_re in except_list:
                 module_dict = {"module": mo_re.module, "pod": mo_re.pod, "path": modules_name + "/" + mo_re.module}
@@ -577,7 +579,7 @@ def auto_release_path(filepath, git, pod, branch, new_tag):
     pul_status = os.system(git_pull_command)
     # print("执行 " + git_pull_command)
     if not pul_status == 0:
-        print("代码冲突了")
+        debugInfo("代码冲突了")
         return ""
     dev_branch_tag = get_version_for(pod + ".podspec")
     new_tag_p = dev_branch_tag
@@ -701,7 +703,7 @@ def new_branch(filepath, git, f_branch, f_tag, n_branch):
     # master分支下的版本号
     repoGit = RepoGit(proj_path=filepath)
     branchs = repoGit.get_branches()
-    debugInfo(str(branchs))
+    # debugInfo(str(branchs))
     os.chdir(filepath)
     if n_branch in branchs:
         debugInfo(n_branch + "分支已存在")
@@ -948,21 +950,21 @@ def release_branch(module_list, include_list, tag_path, c_path, f_branch):
     if len(include_list) > 0:
         invert_list = [i for i in invert_list if i.module in include_list]
 
-    bar = Bar('release...\n', fill="*", max=len(invert_list))
+    bar = Bar('release...', fill="*", max=len(invert_list))
     for a in invert_list:
         bar.next()
         if not (a.branch and len(a.branch) > 0) and not (a.tag and len(a.tag) > 0):
             a.branch = f_branch
         if a.branch and len(a.branch) > 0:
-                filename = get_filename(a.git)
-                module_path = tag_path + filename + "/"
-                create_tag = auto_release_path(module_path, a.git, a.pod, a.branch, a.new_tag)
-                result = 0
-                if create_tag and len(create_tag) > 0:
-                    result = 1
-                    a.new_tag = create_tag
-                merge_model = ModuleStatusModel(a.module, a.pod, result, a.branch, tag=create_tag)
-                merge_result.append(merge_model)
+            filename = get_filename(a.git)
+            module_path = tag_path + filename + "/"
+            create_tag = auto_release_path(module_path, a.git, a.pod, a.branch, a.new_tag)
+            result = 0
+            if create_tag and len(create_tag) > 0:
+                result = 1
+                a.new_tag = create_tag
+            merge_model = ModuleStatusModel(a.module, a.pod, result, a.branch, tag=create_tag)
+            merge_result.append(merge_model)
 
         index += 1
         os.chdir(c_path)
@@ -1002,36 +1004,28 @@ def save_dict_to_yaml(dict_value: dict, save_path: str):
 # branch 组件新分支名字
 class yhgit:
 
-    # # 初始化
-    # def __init__(self):
-    #     """
-    #     基于项目git地址拉取代码，并通过读取PodfileModule中的组件依赖，来新建开发分支n_branch，或者更新本地仓库
-    #     :param git: 工程git地址
-    #     :param branch: 基于哪个分支新建开发分支， 默认master
-    #     :param tag: 基于哪个tag来新建开发分支， 默认不指定
-    #     :param path: 项目的路径，默认~/Desktop/Project/ + 项目名
-    #     :param n_branch: 新分支名， 默认当前年月日
-    #     """
-    #     _project_path = path
-    #     if not (_project_path and len(_project_path) > 0):
-    #         (file, ext) = os.path.splitext(git)
-    #         (path, filename) = os.path.split(git)
-    #         project_name = filename.replace(ext, "")
-    #         _project_path = "~/Desktop/Project/" + project_name + "/"
-    #     self.path = _project_path
-    #
-    #     _n_branch = n_branch
-    #     if not (_n_branch and len(_n_branch) > 0):
-    #         today = datetime.date.today()
-    #         for_today = today.strftime("%y%m%d")
-    #         _n_branch = for_today
-    #     self.n_branch = _n_branch
-    #
-    #     self.git = git
-    #     self.branch = branch
-    #     self.tag = tag
+    # 拉取壳工程代码
+    def clone(self, git, o_branch, n_branch):
+        f_path = os.getcwd()
+        os.chdir(f_path)
+        result = new_branch(f_path, git, o_branch, '', n_branch)
+        res = 0
+        if result and len(result):
+            res = 1
+        error = '分支创建失败'
+        if result and len(result):
+            error = ''
+        resultModule = [ModuleStatusModel("壳工程拉取成功", "壳工程拉取成功", res, n_branch, error, git=git)]
+        succ_list = []
+        fail_list = []
+        for merg_Model in resultModule:
+            if merg_Model.result == 1:
+                succ_list.append(merg_Model)
+            else:
+                fail_list.append(merg_Model)
+        printTable(succ_list, "分支创建成功的模块")
+        printTable(fail_list, "分支创建失败的模块")
 
-    # def __init__(self):
     def init(self, n_branch, git):
         """
         如果本地没有PodfileModule，该命令会自动生成PodfileModule文件，然后可以使用后续指令进行状态检测，推拉代码，提交及打tag的操作，如果有就会只执行后续的新增分支及拉取代码的操作
@@ -1054,17 +1048,20 @@ class yhgit:
         error = ""
         res = 1
         newfile_name = ""
-        debugInfo("执行结果" + result)
+        # debugInfo("执行结果" + result)
         if result and len(result) > 0:
             # 新分支创建成功
             # 更新模块的名字{file_name}为{podspec}名字
             debugInfo(module_path)
             files = [filename for filename in os.listdir(f_path + "/" + module_path) if filename.endswith(".podspec")]
-            debugInfo(files)
+            # debugInfo(files)
             if len(files) > 0:
                 newfile_name = files[0]
                 newfile_name, file_ext = os.path.splitext(newfile_name)
-            debugInfo("执行结果" + newfile_name)
+
+            isSame = file_name and len(file_name) > 0 and newfile_name and len(newfile_name) > 0 and newfile_name == file_name
+
+            # debugInfo("执行结果" + newfile_name)
             newfile_path = modules_path + newfile_name
             # 判断是否有newfile_name对应的文件夹
             find = False
@@ -1077,12 +1074,17 @@ class yhgit:
             else:
                 # 删除旧的文件夹
                 if os.path.exists(f_path + "/" + module_path):
-                    del_dir(f_path + "/" + module_path)
-                res = 1
-                error = "存在同名文件夹，新建分支失败，请手动切换"
+                    if not isSame:
+                        del_dir(f_path + "/" + module_path)
+                        res = 1
+                        error = "存在同名文件夹，新建分支失败，请手动切换"
+                    else:
+                        res = 1
+                        error = "新建分支成功，请手动切换"
+
         # 判断是否有PodfileModule文件夹
         pre_path = f_path + "/"
-        debugInfo(pre_path)
+        # debugInfo(pre_path)
         localyamlPath_ = pre_path + 'PodfileLocal.yaml'
         yamlPath_ = pre_path + 'PodfileModule.yaml'
         localyamlPath = c_path + 'PodfileLocal.yaml'
@@ -1090,9 +1092,6 @@ class yhgit:
         if os.path.exists(localyamlPath_) and os.path.getsize(localyamlPath) == 0:
             del_path(localyamlPath_)
 
-        debugInfo("yaml的路基" + yamlPath_ + "是否存在路基" + str(os.path.exists(yamlPath_)))
-        debugInfo("yamlPath的路基" + yamlPath + "文件大小" + str(os.path.getsize(yamlPath)))
-
         if os.path.exists(yamlPath_) and os.path.getsize(yamlPath) == 0:
             del_path(yamlPath_)
 
@@ -1104,7 +1103,7 @@ class yhgit:
             podmodule_data = {"version": "1.0.0", "branch": str(n_branch), "dependencies": after_convert}
             save_dict_to_yaml(podmodule_data, yamlPath)
 
-        branch_res = [ModuleStatusModel(newfile_name, newfile_name, res, n_branch, error)]
+        branch_res = [ModuleStatusModel(newfile_name, newfile_name, res, n_branch, error, git=git)]
         update_module_files(yamlPath, localyamlPath, branch_res, n_branch, modules_name)
         succ_list = []
         fail_list = []
